pub struct RBCalibrations {
pub rb_id: u8,
pub d_v: f32,
pub timestamp: u32,
pub serialize_event_data: bool,
pub v_offsets: [[f32; 1024]; 9],
pub v_dips: [[f32; 1024]; 9],
pub v_inc: [[f32; 1024]; 9],
pub tbin: [[f32; 1024]; 9],
pub vcal_data: Vec<RBEvent>,
pub tcal_data: Vec<RBEvent>,
pub noi_data: Vec<RBEvent>,
}Fields
rb_id: u8d_v: f32timestamp: u32serialize_event_data: boolv_offsets: [[f32; 1024]; 9]v_dips: [[f32; 1024]; 9]v_inc: [[f32; 1024]; 9]tbin: [[f32; 1024]; 9]vcal_data: Vec<RBEvent>tcal_data: Vec<RBEvent>noi_data: Vec<RBEvent>Implementations
Sourceimpl RBCalibrations
impl RBCalibrations
pub const NSKIP: usize = 2
pub const SINMAX: usize = 60
pub const DVCUT: f32 = 15.0
pub const NOMINALFREQ: f32 = 2.0
pub const CALFREQ: f32 = 0.025
Sourcepub fn assemble_from_flightcal(
fcal_t: RBCalibrationFlightT,
fcal_v: RBCalibrationFlightV,
) -> Result<Self, CalibrationError>
pub fn assemble_from_flightcal( fcal_t: RBCalibrationFlightT, fcal_v: RBCalibrationFlightV, ) -> Result<Self, CalibrationError>
Re-assemble a RBCalibration from chopped up parts
Sourcepub fn emit_flighttcal(&self) -> RBCalibrationFlightT
pub fn emit_flighttcal(&self) -> RBCalibrationFlightT
Return the timing part of the calibration in a package digestable by the flight computer.
Additonal compression by using f16
Sourcepub fn emit_flightvcal(&self) -> RBCalibrationFlightV
pub fn emit_flightvcal(&self) -> RBCalibrationFlightV
Return the voltage part of the calibration in a package digestable by the flight computer.
Additional compression by using f16
Sourcepub fn clean_input_data(&mut self)
pub fn clean_input_data(&mut self)
Remove events with invalid traces or event fragment bits set
pub fn apply_vcal_constants( &self, adc: &Vec<f32>, channel: usize, stop_cell: usize, ) -> Vec<f32>
Sourcepub fn timing_calibration(
&self,
edge: &Edge,
apply_vcal: bool,
) -> Result<Vec<Vec<f32>>, CalibrationError>
pub fn timing_calibration( &self, edge: &Edge, apply_vcal: bool, ) -> Result<Vec<Vec<f32>>, CalibrationError>
Sourcepub fn calibrate(&mut self) -> Result<(), CalibrationError>
pub fn calibrate(&mut self) -> Result<(), CalibrationError>
Call to the calibration routine, using the set input data
Sourcepub fn spike_cleaning(
voltages: &mut Vec<Vec<f32>>,
stop_cell: u16,
) -> Result<(), WaveformError>
pub fn spike_cleaning( voltages: &mut Vec<Vec<f32>>, stop_cell: u16, ) -> Result<(), WaveformError>
Apply the spike cleaning to all channels
Sourcepub fn voltages(
&self,
channel: usize,
stop_cell: usize,
adc: &Vec<u16>,
waveform: &mut Vec<f32>,
)
pub fn voltages( &self, channel: usize, stop_cell: usize, adc: &Vec<u16>, waveform: &mut Vec<f32>, )
Apply the voltage calibration to a single channel FIXME - mixing of naming conventions for the channels
FIXME - make it return Result<(), CalibrationError>
Arguments
- channel : Channel id 1-9
- stop_cell : This channels stop cell
- adc : Uncalibrated channel data
- waveform : Pre-allocated array to hold calibrated waveform data.
Sourcepub fn nanoseconds(
&self,
channel: usize,
stop_cell: usize,
times: &mut Vec<f32>,
)
pub fn nanoseconds( &self, channel: usize, stop_cell: usize, times: &mut Vec<f32>, )
Apply the timing calibration to a single channel
This will allocate the array for the waveform time bins (unit is ns)
Arguments
- channel : Channel id 1-9
- stop_cell : This channels stop cell
pub fn new(rb_id: u8) -> Self
Sourcepub fn discard_data(&mut self)
pub fn discard_data(&mut self)
Discard the data to reduce the memory footprint
Sourcepub fn from_file(
filename: String,
discard_data: bool,
) -> Result<Self, SerializationError>
pub fn from_file( filename: String, discard_data: bool, ) -> Result<Self, SerializationError>
Gets the calibration from a file which has the RBCalibration stored in a TofPacket
E.g. if it was written with TofPacketWriter
Sourcepub fn get_id_from_filename(&mut self, filename: &Path) -> u8
pub fn get_id_from_filename(&mut self, filename: &Path) -> u8
Infer the readoutboard id from the filename
Assuming a certain naming scheme for the filename “rbXX_cal.txt” we extract the readoutboard id
Sourcepub fn passes_timing_checks(&self) -> bool
pub fn passes_timing_checks(&self) -> bool
Self check if the timing constants are sane
Sourcepub fn passes_voltage_checks(&self) -> bool
pub fn passes_voltage_checks(&self) -> bool
Self check if the voltage constants are sane
Sourcepub fn check(&self) -> bool
pub fn check(&self) -> bool
Check voltage and timing constants for sanity
for each RB channel take distribution of 1024 calibration constants and confirm
Tcal: average value between 0.48824 and 0.48834 standard deviation between 0.08 and 0.15. Most common problem: avg of tcal distribution is < 0.48824
Vcal1 (offsets): average value between 4200 and 5200 standard deviation less than 150
Vcal2 (droop): average value between -0.5 and 0.5 print out a warning if the standard deviation for any channel is > 5.0 Note that ch1 on any particular board has a more dramatic droop so if ch1 droop is the only channel on the board with this warning, it can be ignored
Vcal3 (gain): average value between 0.06 and 0.07 standard deviation less than 0.00025